SpinBox — pyqtgraph 0.11.0rc0 documentation

# SpinBox

class `pyqtgraph.` `SpinBox`(parent=None, value=0.0, **kwargs)

  Bases: QtGui.QAbstractSpinBox

  Extension of QSpinBox widget for selection of a numerical value. Adds many extra features:

  - SI prefix notation (eg, automatically display “300 mV” instead of “0.003 V”)

  - Float values with linear and decimal stepping (1-9, 10-90, 100-900, etc.)

  - Option for unbounded values

  - Delayed signals (allows multiple rapid changes with only one change signal)

  - Customizable text formatting

  Signals: |
  valueChanged(value) | Same as QSpinBox; emitted every time the value has changed.
  sigValueChanged(self) | Emitted when value has changed, but also combines multiple rapid changes into one signal (eg, when rolling the mouse wheel).
  sigValueChanging(self, value) | Emitted immediately for all value changes.

  `__init__`(parent=None, value=0.0, **kwargs)

    Arguments: |
    parent | Sets the parent widget for this SpinBox (optional). Default is None.
    value | (float/int) initial value. Default is 0.0.

    All keyword arguments are passed to `setOpts()`.

  `editingFinishedEvent`()

    Edit has finished; set value.

  `event`(self, event: PySide2.QtCore.QEvent) → bool
  `fixup`(self, input: str)
  `focusInEvent`(self, event: PySide2.QtGui.QFocusEvent)
  `interpret`()

    Return value of text or False if text is invalid.

  `paintEvent`(self, event: PySide2.QtGui.QPaintEvent)
  `selectNumber`()

    Select the numerical portion of the text to allow quick editing by the user.

  `setDecimals`(decimals)

    Set the number of decimals to be displayed when formatting numeric values.

  `setMaximum`(m, update=True)

    Set the maximum allowed value (or None for no limit)

  `setMinimum`(m, update=True)

    Set the minimum allowed value (or None for no limit)

  `setOpts`(**opts)

    Set options affecting the behavior of the SpinBox.

    Arguments: |
    bounds | (min,max) Minimum and maximum values allowed in the SpinBox. Either may be None to leave the value unbounded. By default, values are unbounded.
    suffix | (str) suffix (units) to display after the numerical value. By default, suffix is an empty str.
    siPrefix | (bool) If True, then an SI prefix is automatically prepended to the units and the value is scaled accordingly. For example, if value=0.003 and suffix=’V’, then the SpinBox will display “300 mV” (but a call to SpinBox.value will still return 0.003). Default is False.
    step | (float) The size of a single step. This is used when clicking the up/ down arrows, when rolling the mouse wheel, or when pressing keyboard arrows while the widget has keyboard focus. Note that the interpretation of this value is different when specifying the ‘dec’ argument. Default is 0.01.
    dec | (bool) If True, then the step value will be adjusted to match the current size of the variable (for example, a value of 15 might step in increments of 1 whereas a value of 1500 would step in increments of 100). In this case, the ‘step’ argument is interpreted relative to the current value. The most common ‘step’ values when dec=True are 0.1, 0.2, 0.5, and 1.0. Default is False.
    minStep | (float) When dec=True, this specifies the minimum allowable step size.
    int | (bool) if True, the value is forced to integer type. Default is False
    wrapping | (bool) If True and both bounds are not None, spin box has circular behavior.
    decimals | (int) Number of decimal values to display. Default is 6.
    format | (str) Formatting string used to generate the text shown. Formatting is done with `str.format()` and makes use of several arguments: value - the unscaled value of the spin box suffix - the suffix string scaledValue - the scaled value to use when an SI prefix is present siPrefix - the SI prefix string (if any), or an empty string if this feature has been disabled suffixGap - a single space if a suffix is present, or an empty string otherwise.
    regex | (str or RegexObject) Regular expression used to parse the spinbox text. May contain the following group names: number - matches the numerical portion of the string (mandatory) siPrefix - matches the SI prefix string suffix - matches the suffix string Default is defined in `pyqtgraph.functions.FLOAT_REGEX`.
    evalFunc | (callable) Fucntion that converts a numerical string to a number, preferrably a Decimal instance. This function handles only the numerical of the text; it does not have access to the suffix or SI prefix.
    compactHeight | (bool) if True, then set the maximum height of the spinbox based on the height of its font. This allows more compact packing on platforms with excessive widget decoration. Default is True.

  `setPrefix`(p)

    Set a string prefix.

  `setProperty`(self, name: str, value: typing.Any) → bool
  `setRange`(r0, r1)

    Set the upper and lower limits for values in the spinbox.

  `setSingleStep`(step)

    Set the step size used when responding to the mouse wheel, arrow buttons, or arrow keys.

  `setSuffix`(suf)

    Set the string suffix appended to the spinbox text.

  `setValue`(value=None, update=True, delaySignal=False)

    Set the value of this SpinBox.

    If the value is out of bounds, it will be clipped to the nearest boundary or wrapped if wrapping is enabled.

    If the spin is integer type, the value will be coerced to int. Returns the actual value set.

    If value is None, then the current value is used (this is for resetting the value after bounds, etc. have changed)

  `setWrapping`(s)

    Set whether spin box is circular.

    Both bounds must be set for this to have an effect.

  `sizeHint`(self) → PySide2.QtCore.QSize
  `stepBy`(self, steps: int)
  `stepEnabled`(self) → PySide2.QtWidgets.QAbstractSpinBox.StepEnabled
  `validate`(self, input: str, pos: int) → PySide2.QtGui.QValidator.State
  `value`()

    Return the value of this SpinBox.

  `wrapping`()

    Return whether or not the spin box is circular.